@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Get XML.
 has xml => (
@@ -38,9 +38,11 @@ Map::Tube::Prague - Interface to the Prague Metro Map.
  use Map::Tube::Prague;
  my $obj = Map::Tube::Prague->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
  my $route = $obj->get_shortest_route($from, $to);
+ my $stations_ar = $obj->get_stations($line);
  my $metro_name = $obj->name;
  my $xml_file = $obj->xml;
 
@@ -64,6 +66,11 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_lines()>
+
+ Get lines in metro map.
+ Returns reference to array with Map::Tube::Line objects.
+
 =item C<get_node_by_id($station_id)>
 
  Get station node by id.
@@ -79,6 +86,11 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
  Returns Map::Tube::Route object.
 
+=item C<get_stations($line)>
+
+ Get list of stations for concrete metro line.
+ Returns reference to array with Map::Tube::Node objects.
+
 =item C<name()>
 
  Get metro name.
@@ -153,7 +165,7 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
          'callback_node' => \&node_color_without_label,
          'driver' => 'neato',
          'tube' => $obj,
- ); 
+ );
 
  # Get graph to file.
  $g->graph('Prague.png');
@@ -162,11 +174,13 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  system "ls -l Prague.png";
 
  # Output like:
- # -rw-r--r-- 1 skim skim 292500 Dec 21 17:25 Prague.png
+ # -rw-r--r-- 1 skim skim 175854 Jan 25 01:20 Prague.png
 
 =begin html
 
-<img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Prague/master/images/Prague.png" alt="Pražské metro" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Prague/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Prague/master/images/ex3.png" alt="Pražské metro" width="300px" height="300px" />
+</a>
 
 =end html
 
@@ -180,12 +194,16 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
-L<Map::Tube::Text::Table>.
+L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Table>,
+L<Task::Map::Tube>.
 
 L<Map::Tube::Barcelona>,
 L<Map::Tube::Berlin>,
 L<Map::Tube::Bucharest>,
+L<Map::Tube::Budapest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
 L<Map::Tube::Kazan>,
@@ -194,13 +212,15 @@ L<Map::Tube::Kiev>,
 L<Map::Tube::London>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
-L<Map::Tube::Novosibirsk>,
 L<Map::Tube::NYC>,
+L<Map::Tube::Nanjing>,
+L<Map::Tube::Novosibirsk>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
 L<Map::Tube::Sofia>,
 L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
+L<Map::Tube::Vienna>,
 L<Map::Tube::Warsaw>,
 L<Map::Tube::Yekaterinburg>.
 
@@ -216,12 +236,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014 Michal Špaček
+ © 2014-2015 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
